@@ -1,11 +1,11 @@
 /*
-  SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include <QWidget>
 #include <QVBoxLayout>
+#include <QWidget>
 
 #include <QApplication>
 #include <QCommandLineParser>
@@ -20,10 +20,10 @@ int main(int argc, char *argv[])
     parser.addHelpOption();
     parser.process(app);
 
-    QWidget *w = new QWidget;
-    auto *vbox = new QVBoxLayout(w);
+    auto w = new QWidget;
+    auto vbox = new QVBoxLayout(w);
 
-    PimCommon::SpellCheckLineEdit *spellCheckLineEdit = new PimCommon::SpellCheckLineEdit(w, QStringLiteral("testspecklineeditrc"));
+    auto spellCheckLineEdit = new PimCommon::SpellCheckLineEdit(w, QStringLiteral("testspecklineeditrc"));
     vbox->addWidget(spellCheckLineEdit);
     vbox->addStretch();
 
